@@ -11,6 +11,11 @@ def output(video_extractor, pretty_print=True):
     out['title'] = ve.title
     out['site'] = ve.name
     out['streams'] = ve.streams
+    try:
+        if ve.audiolang:
+            out['audiolang'] = ve.audiolang
+    except AttributeError:
+        pass
     if pretty_print:
         print(json.dumps(out, indent=4, sort_keys=True, ensure_ascii=False))
     else:
@@ -31,6 +36,11 @@ def print_info(site_info=None, title=None, type=None, size=None):
 
 def download_urls(urls=None, title=None, ext=None, total_size=None, refer=None):
     ve = last_info
+    if not ve:
+        ve = VideoExtractor()
+        ve.name = ''
+        ve.url = urls
+        ve.title=title
     # save download info in streams
     stream = {}
     stream['container'] = ext
